@@ -34,12 +34,13 @@
 
 #pragma warning(push, 0)	// no warnings from includes - begin
 #include <QDebug>
-#include <QThread>
+#include <QtConcurrentRun>
 #include <QPixmap>
 #include <QPainter>
 #include <QBitmap>
 #include <qmath.h>
 #include <QSvgRenderer>
+#include <QTimer>
 #pragma warning(pop)		// no warnings from includes - end
 
 #if defined(Q_OS_WIN) && !defined(SOCK_STREAM)
@@ -314,15 +315,15 @@ float DkImage::getBufferSizeFloat(const QSize& imgSize, const int depth) {
  * @param interpolation the interpolation method
  * @return QImage the resized image
  **/ 
-QImage DkImage::resizeImage(const QImage& img, const QSize& newSize, float factor /* = 1.0f */, int interpolation /* = ipl_cubic */, bool correctGamma /* = true */) {
+QImage DkImage::resizeImage(const QImage& img, const QSize& newSize, double factor /* = 1.0 */, int interpolation /* = ipl_cubic */, bool correctGamma /* = true */) {
 
 	QSize nSize = newSize;
 
 	// nothing to do
-	if (img.size() == nSize && factor == 1.0f)
+	if (img.size() == nSize && factor == 1.0)
 		return img;
 
-	if (factor != 1.0f)
+	if (factor != 1.0)
 		nSize = QSize(qRound(img.width()*factor), qRound(img.height()*factor));
 
 	if (nSize.width() < 1 || nSize.height() < 1) {
@@ -383,7 +384,6 @@ QImage DkImage::resizeImage(const QImage& img, const QSize& newSize, float facto
 		return qImg;
 
 	} catch (std::exception se) {
-
 		return QImage();
 	}
 
@@ -900,8 +900,6 @@ QImage DkImage::cropToImage(const QImage & src, const DkRotatingRect & rect, con
 	if (cImgSize.x() < 0.5f || cImgSize.y() < 0.5f)
 		return src;
 
-	qDebug() << cImgSize;
-
 	double angle = DkMath::normAngleRad(rect.getAngle(), 0, CV_PI*0.5);
 	double minD = qMin(std::abs(angle), std::abs(angle-CV_PI*0.5));
 
@@ -1130,8 +1128,7 @@ QPixmap DkImage::loadIcon(const QString & filePath, const QSize& size) {
 
 	QPixmap icon = loadFromSvg(filePath, s);
 	
-	if (!DkSettingsManager::param().display().defaultIconColor || DkSettingsManager::param().app().privateMode)
-		icon = colorizePixmap(icon, DkSettingsManager::param().display().iconColor);
+	icon = colorizePixmap(icon, DkSettingsManager::param().display().iconColor);
 
 	return icon;
 }
@@ -1546,17 +1543,28 @@ QColor DkImage::getMeanColor(const QImage& img) {
 DkImageStorage::DkImageStorage(const QImage& img) {
 	mImg = img;
 
-	mComputeThread = new QThread;
-	mComputeThread->start();
-	moveToThread(mComputeThread);
+	mWaitTimer = new QTimer(this);
+	mWaitTimer->setSingleShot(true);
+	mWaitTimer->setInterval(100);
+	
+	init();
 
-	connect(DkActionManager::instance().action(DkActionManager::menu_view_anti_aliasing), SIGNAL(toggled(bool)), this, SLOT(antiAliasingChanged(bool)));
+	connect(mWaitTimer, SIGNAL(timeout()), this, SLOT(compute()), Qt::UniqueConnection);
+	connect(&mFutureWatcher, SIGNAL(finished()), this, SLOT(imageComputed()), Qt::UniqueConnection);
+	connect(DkActionManager::instance().action(DkActionManager::menu_view_anti_aliasing), SIGNAL(toggled(bool)), this, SLOT(antiAliasingChanged(bool)), Qt::UniqueConnection);
+}
+
+void DkImageStorage::init() {
+
+	mComputeState = l_not_computed;
+	mScaledImg = QImage();
+	mWaitTimer->stop();
+	mScale = 1.0;
 }
 
 void DkImageStorage::setImage(const QImage& img) {
 
-	mStop = true;
-	mImgs.clear();	// is it save (if the thread is still working?)
+	init();
 	mImg = img;
 }
 
@@ -1564,10 +1572,8 @@ void DkImageStorage::antiAliasingChanged(bool antiAliasing) {
 
 	DkSettingsManager::param().display().antiAliasing = antiAliasing;
 
-	if (!antiAliasing) {
-		mStop = true;
-		mImgs.clear();
-	}
+	if (!antiAliasing)
+		init();
 
 	emit infoSignal((antiAliasing) ? tr("Anti Aliasing Enabled") : tr("Anti Aliasing Disabled"));
 	emit imageUpdated();
@@ -1579,86 +1585,88 @@ QImage DkImageStorage::getImageConst() const {
 	return mImg;
 }
 
-QImage DkImageStorage::getImage(float factor) {
+QImage DkImageStorage::getImage(double scale) {
 
-	if (factor >= 0.5f || mImg.isNull() || !DkSettingsManager::param().display().antiAliasing)
+	if (scale >= 1.0 || mImg.isNull() || !DkSettingsManager::param().display().antiAliasing)
 		return mImg;
 
-	// check if we have an image similar to that requested
-	for (int idx = 0; idx < mImgs.size(); idx++) {
+	QSize s = mImg.size() * scale;
 
-		if ((float)mImgs.at(idx).height()/mImg.height() >= factor)
-			return mImgs.at(idx);
-	}
+	if (s == mScaledImg.size())
+		return mScaledImg;
 
-	// if the image does not exist - create it
-	if (!mBusy && mImgs.empty() && /*img.colorTable().isEmpty() &&*/ mImg.width() > 32 && mImg.height() > 32) {
-		mStop = false;
-		// nobody is busy so start working
-		QMetaObject::invokeMethod(this, "computeImage", Qt::QueuedConnection);
+	if (mComputeState != l_computing) {
+		// trigger a new computation
+		init();
+		mScale = scale;
+		mWaitTimer->start();
 	}
 
 	// currently no alternative is available
 	return mImg;
 }
 
-void DkImageStorage::computeImage() {
+void DkImageStorage::compute() {
 
-	// obviously, computeImage gets called multiple times in some wired cases...
-	if (!mImgs.empty())
+	if (mComputeState == l_computed) {
+		emit imageUpdated();
+		qDebug() << "image is up-to-date in DkImageStorage::compute...";
 		return;
-
-	DkTimer dt;
-	mBusy = true;
-	QImage resizedImg = mImg;
-	
-
-	// down sample the image until it is twice times full HD
-	QSize iSize = mImg.size();
-	while (iSize.width() > 2*1920 && iSize.height() > 2*1920)	// in general we need less than 200 ms for the whole downscaling if we start at 1500 x 1500
-		iSize *= 0.5;
-
-	// for extreme panorama images the Qt scaling crashes (if we have a width > 30000) so we simply 
-	if (qMax(iSize.width(), iSize.height()) < 20000)
-		resizedImg = resizedImg.scaled(iSize, Qt::KeepAspectRatio, Qt::FastTransformation);
-
-	// it would be pretty strange if we needed more than 30 sub-images
-	for (int idx = 0; idx < 30; idx++) {
-
-		QSize s = resizedImg.size();
-		s *= 0.5;
-
-		if (s.width() < 32 || s.height() < 32)
-			break;
-
-#ifdef WITH_OPENCV
-		cv::Mat rImgCv = DkImage::qImage2Mat(resizedImg);
-		cv::Mat tmp;
-		cv::resize(rImgCv, tmp, cv::Size(s.width(), s.height()), 0, 0, CV_INTER_AREA);
-		resizedImg = DkImage::mat2QImage(tmp);
-#else
-		resizedImg = resizedImg.scaled(s, Qt::KeepAspectRatio, Qt::SmoothTransformation);
-#endif
-
-		// new image assigned?
-		if (mStop)
-			break;
-
-		mMutex.lock();
-		mImgs.push_front(resizedImg);
-		mMutex.unlock();
 	}
 
-	mBusy = false;
+	if (mComputeState == l_computing)	// don't compute twice
+		return;
 
-	// tell my caller I did something
-	emit imageUpdated();
-
-	qDebug() << "pyramid computation took me: " << dt << " layers: " << mImgs.size();
-
-	if (mImgs.size() > 6)
-		qDebug() << "layer size > 6: " << mImg.size();
+	mComputeState = l_computing;
 
+	mFutureWatcher.setFuture(QtConcurrent::run(this, &nmc::DkImageStorage::computeIntern, mImg, mScale));
 }
 
+QImage DkImageStorage::computeIntern(const QImage & src, double scale) {
+	
+	if (scale >= 1.0)
+		return src;
+
+	DkTimer dt;
+	QImage resizedImg = src;
+
+	if (!DkSettingsManager::param().display().highQualityAntiAliasing) {
+		QSize cs = src.size();
+
+		// fast down sampling until the image is twice times full HD
+		while (qMin(cs.width(), cs.height()) > 2 * 4000) {
+			cs *= 0.5;
+		}
+
+		// for extreme panorama images the Qt scaling crashes (if we have a width > 30000) so we simply 
+		if (cs != mImg.size()) {
+			resizedImg = resizedImg.scaled(cs, Qt::KeepAspectRatio, Qt::FastTransformation);
+		}
+	}
+
+	QSize s = mImg.size() * scale;
+
+#ifdef WITH_OPENCV
+	cv::Mat rImgCv = DkImage::qImage2Mat(resizedImg);
+	cv::Mat tmp;
+	cv::resize(rImgCv, tmp, cv::Size(s.width(), s.height()), 0, 0, CV_INTER_AREA);
+	resizedImg = DkImage::mat2QImage(tmp);
+#else
+	resizedImg = resizedImg.scaled(s, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+#endif
+
+	return resizedImg;
+}
+
+void DkImageStorage::imageComputed() {
+
+	mScaledImg = mFutureWatcher.result();
+
+	mComputeState = (mScaledImg.isNull()) ? l_empty : l_computed;
+
+	if (mComputeState == l_computed)
+		emit imageUpdated();
+	else
+		qWarning() << "could not compute scale factor" << mScale;
+}
 }
