@@ -143,160 +143,7 @@ QVector<DkPackage> DkXmlUpdateChecker::parse(QXmlStreamReader& reader) const {
 	return packages;
 }
 
-
-// DkInstallUpdater --------------------------------------------------------------------
-DkInstallUpdater::DkInstallUpdater(QObject* parent) : QObject(parent) {
-
-}
-
-void DkInstallUpdater::checkForUpdates(bool silent) {
-
-	mSilent = silent;
-
-	DkSettingsManager::param().sync().lastUpdateCheck = QDate::currentDate();
-	DkSettingsManager::param().save();
-
-	QUrl url ("http://download.nomacs.org/repository/Updates.xml");
-
-	// this is crucial since every item creates it's own http thread
-	if (!mManager) {
-		mManager = new QNetworkAccessManager(this);
-		connect(mManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(replyFinished(QNetworkReply*)));
-	}
-
-	// the proxy settings take > 2 sec on Win7
-	// that is why proxy settings are only set
-	// for manual updates
-	if (!silent) {
-		DkTimer dt;
-		QNetworkProxyQuery npq(url);
-		QList<QNetworkProxy> listOfProxies = QNetworkProxyFactory::systemProxyForQuery(npq);
-
-		if (!listOfProxies.empty() && listOfProxies[0].hostName() != "") {
-			mManager->setProxy(listOfProxies[0]);
-		}
-		qDebug() << "checking for proxy takes: " << dt;
-	}
-
-	mManager->get(QNetworkRequest(url));
-	qDebug() << "checking updates at: " << url;
-
-}
-
-void DkInstallUpdater::replyFinished(QNetworkReply* reply) {
-
-	QString redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-	qDebug() << "--------------------------";
-
-	if (!redirect.isEmpty()) {
-		//qDebug() << "redirecting: " << redirect;
-		checkForUpdates(false);
-		reply->close();
-		return;
-	}
-
-	if (!reply->isFinished()) {
-		qDebug() << "reply not finished...";
-		reply->close();		
-		return;
-	}
-
-	if (reply->error() != QNetworkReply::NoError) {
-		qDebug() << "could not check for updates: " << reply->errorString();
-		reply->close();
-		return;
-	}
-
-	QFile componentsXml(QCoreApplication::applicationDirPath() + "/../components.xml");
-
-	if (!componentsXml.exists()) {
-		qDebug() << "Sorry, " << componentsXml.fileName() << "does not exist";
-		return;
-	}
-
-	componentsXml.open(QIODevice::ReadOnly);
-	QXmlStreamReader localReader(componentsXml.readAll());
-	QXmlStreamReader remoteReader(reply);
-
-	DkXmlUpdateChecker checker;
-	QVector<DkPackage> newPackages = checker.updatesAvailable(localReader, remoteReader);
-	if (!newPackages.empty()) {
-
-		bool update = true;
-
-		if (mSilent) {	// ask user before updating if a silent check was performed
-			QString msg = tr("There are new packages available: ") + "\n";
-
-			for (const DkPackage& p : newPackages)
-				msg += "\t" + p.name() + " " + p.version() + "\n";
-
-			QMessageBox* msgBox = new QMessageBox(
-				QMessageBox::Information, 
-				tr("Updates Available"), 
-				msg, 
-				QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel,
-				DkUtils::getMainWindow());
-
-			msgBox->button(QMessageBox::Yes)->setText(tr("&Upgrade"));
-			msgBox->button(QMessageBox::Cancel)->setText(tr("Remind Me &Later"));
-			msgBox->button(QMessageBox::No)->setText(tr("&Skip this Version"));
-
-			int result = msgBox->exec();
-
-			update = result == QMessageBox::Accepted || result == QMessageBox::Yes;
-
-			if (result == QMessageBox::No)	// do not show again
-				DkSettingsManager::param().sync().updateDialogShown = true;	
-
-			msgBox->deleteLater();
-		}
-
-		if (update)
-			updateNomacs("--updater");
-	}
-	else if (!mSilent) {
-		QMessageBox::information(DkUtils::getMainWindow(), tr("nomacs Updates"), tr("nomacs is up-to-date"));
-	}
-	else
-		qDebug() << "nomacs is up-to-date...";
-	qDebug() << "--------------------------";
-}
-
-bool DkInstallUpdater::updateNomacs(const QString& cmd) {
-
-	QFileInfo updater(QCoreApplication::applicationDirPath() + "/../maintenancetool.exe");
-
-	if (!updater.exists()) {
-		qDebug() << "Sorry, " << updater.absoluteFilePath() << "does not exist";
-		return false;
-	}
-
-#ifdef Q_OS_WIN
-
-	// diem: 14.12.2015 - NOTE we need this win API command only to fix a qt installer bug: https://bugreports.qt.io/browse/QTIFW-746
-	// hence after updating the installer (> 2.0.1) we can safely fall back to the Qt cmd....
-	std::wstring upath = DkUtils::qStringToStdWString(updater.absoluteFilePath());
-	std::wstring cmdW = DkUtils::qStringToStdWString(cmd);
-
-	HINSTANCE h = ShellExecuteW( NULL, 
-		L"runas",  
-		upath.data(),  
-		cmdW.data(),     
-		NULL,                        // default dir 
-		SW_SHOWNORMAL  
-		); 
-
-	return h != NULL;
-#else
-	QStringList args;
-	args << cmd;
-
-	return QProcess::startDetached(updater.absoluteFilePath(), args);
-#endif
-}
-
 // DkUpdater  --------------------------------------------------------------------
-
 DkUpdater::DkUpdater(QObject* parent) : QObject(parent) {
 
 	silent = true;
@@ -308,6 +155,15 @@ DkUpdater::DkUpdater(QObject* parent) : QObject(parent) {
 
 void DkUpdater::checkForUpdates() {
 
+	if (DkSettingsManager::param().sync().disableUpdateInteraction) {
+		QMessageBox::critical(
+			DkUtils::getMainWindow(), 
+			tr("Updates Disabled"), 
+			tr("nomacs updates are disabled.\nPlease contact your system administrator for further information."), 
+			QMessageBox::Ok);
+		return;
+	}
+
 	DkSettingsManager::param().sync().lastUpdateCheck = QDate::currentDate();
 	DkSettingsManager::param().save();
 
@@ -506,6 +362,15 @@ DkTranslationUpdater::DkTranslationUpdater(bool silent, QObject* parent) : QObje
 
 void DkTranslationUpdater::checkForUpdates() {
 
+	if (DkSettingsManager::param().sync().disableUpdateInteraction) {
+		QMessageBox::critical(
+			DkUtils::getMainWindow(),
+			tr("Updates Disabled"),
+			tr("nomacs updates are disabled.\nPlease contact your system administrator for further information."),
+			QMessageBox::Ok);
+		return;
+	}
+
 	mTotal = -1;
 	mTotalQt = -1;
 	mReceived = 0;
@@ -554,24 +419,7 @@ void DkTranslationUpdater::replyFinished(QNetworkReply* reply) {
 
 	QDateTime lastModifiedRemote = reply->header(QNetworkRequest::LastModifiedHeader).toDateTime();
 
-
-#ifdef  Q_OS_WIN
-	QDir storageLocation;
-	if (DkSettingsManager::param().isPortable()) {
-		storageLocation = QDir(QCoreApplication::applicationDirPath());
-		storageLocation.cd("translations");
-	}
-	else
-		storageLocation = QDir(QDir::home().absolutePath() + "/AppData/Roaming/nomacs/translations");
-#else
-#if QT_VERSION >= 0x050000
-	QDir storageLocation(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/data/" + QCoreApplication::organizationName() + "/" + QCoreApplication::applicationName());
-#else
-	QDir storageLocation(QDesktopServices::storageLocation(QDesktopServices::DataLocation)+"/translations/");
-#endif
-
-#endif //  Q_OS_WIN
-
+	QDir storageLocation = DkUtils::getTranslationPath();
 	QString translationName = qtTranslation ? "qt_"+ DkSettingsManager::param().global().language + ".qm" : "nomacs_"+ DkSettingsManager::param().global().language + ".qm";
 
 	if (isRemoteFileNewer(lastModifiedRemote, translationName)) {
@@ -589,12 +437,12 @@ void DkTranslationUpdater::replyFinished(QNetworkReply* reply) {
 
 		QString absoluteFilePath = storageLocation.absolutePath() + "/" + basename + extension;
 		if (QFile::exists(absoluteFilePath)) {
-			qDebug() << "File already exists - overwriting";
+			qInfo() << "File already exists - overwriting";
 		}
 
 		QFile file(absoluteFilePath);
 		if (!file.open(QIODevice::WriteOnly)) {
-			qDebug()  << "Could not open " << QFileInfo(file).absoluteFilePath() << "for writing";
+			qWarning()  << "Could not open " << QFileInfo(file).absoluteFilePath() << "for writing";
 			return;
 		}
 
@@ -662,29 +510,14 @@ void DkTranslationUpdater::updateDownloadProgressQt(qint64 received, qint64 tota
 }
 
 bool DkTranslationUpdater::isRemoteFileNewer(QDateTime lastModifiedRemote, const QString& localTranslationName) {
+	
 	if (!lastModifiedRemote.isValid())
 		return false;
 
-#ifdef  Q_OS_WIN
-	QDir storageLocation;
-	if (DkSettingsManager::param().isPortable()) {
-		storageLocation = QDir(QCoreApplication::applicationDirPath());
-		storageLocation.cd("translations");
-	}
-	else
-		storageLocation = QDir(QDir::home().absolutePath() + "/AppData/Roaming/nomacs/translations");
-#else
-#if QT_VERSION >= 0x050000
-	QDir storageLocation(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/data/" + QCoreApplication::organizationName() + "/" + QCoreApplication::applicationName());
-#else
-	QDir storageLocation(QDesktopServices::storageLocation(QDesktopServices::DataLocation)+"/translations/");
-#endif
-
-#endif //  Q_OS_WIN
-	QFile userTranslation(storageLocation.absoluteFilePath(localTranslationName));
-	//qDebug() << "local: " << QFileInfo(userTranslation).lastModified()  << "  remote: " << lastModifiedRemote << " bool: " << (QFileInfo(userTranslation).lastModified() < lastModifiedRemote);
-	//qDebug() << "userTranslation exists:" << userTranslation.exists();
-	return !userTranslation.exists() || (QFileInfo(userTranslation).lastModified() < lastModifiedRemote);
+	QString trPath = DkUtils::getTranslationPath();
+	QFileInfo trFile(trPath, localTranslationName);
+	
+	return !trFile.exists() || (QFileInfo(trFile).lastModified() < lastModifiedRemote);
 }
 
 void DkTranslationUpdater::cancelUpdate() {
