@@ -160,8 +160,12 @@ public:
 
 	static QString getAppDataPath();
 
+	static QString getTranslationPath();
+
 	static QWidget* getMainWindow();
 
+	static void showViewportMessage(const QString& msg);
+
 	/**
 	 * Sleeps n ms.
 	 * This function is based on the QTest::qSleep(int ms)
