@@ -40,6 +40,7 @@
 #include "DkManipulatorWidgets.h"
 #include "DkSettingsWidget.h"
 #include "DkPluginInterface.h"
+#include "DkBasicWidgets.h"
 
 #pragma warning(push, 0)	// no warnings from includes - begin
 #include <QLabel>
@@ -96,11 +97,13 @@ QString DkBatchTabButton::info() const {
 
 void DkBatchTabButton::paintEvent(QPaintEvent *event) {
 
+	QPushButton::paintEvent(event);
+
 	// fixes stylesheets which are not applied to custom widgets
 	QStyleOption opt;
 	opt.init(this);
 	QPainter p(this);
-	style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
+	//style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
 
 	QFont f;
 	f.setPointSize(9);
@@ -116,7 +119,6 @@ void DkBatchTabButton::paintEvent(QPaintEvent *event) {
 
 	p.drawText(QPoint(25, 50), mInfo);
 
-	QPushButton::paintEvent(event);
 }
 
 // DkBatchContainer --------------------------------------------------------------------
@@ -1266,7 +1268,6 @@ void DkProfileWidget::createLayout() {
 	connect(mSummary, SIGNAL(exportCurrentProfile()), this, SLOT(exportCurrentProfile()));
 }
 
-
 bool DkProfileWidget::hasUserInput() const {
 	return false;
 }
@@ -2009,6 +2010,10 @@ void DkBatchTransformWidget::createLayout() {
 
 	mCbCropMetadata = new QCheckBox(tr("&Crop from Metadata"));
 
+	// crop rectangle
+	mCbCropRectangle = new QCheckBox(tr("&Crop Rectangle"));
+	mCropRectWidget = new DkRectWidget(QRect(), this);
+
 	QGridLayout* layout = new QGridLayout(this);
 	layout->setContentsMargins(0, 0, 0, 0);
 	layout->setAlignment(Qt::AlignTop | Qt::AlignLeft);
@@ -2023,6 +2028,9 @@ void DkBatchTransformWidget::createLayout() {
 	layout->addWidget(transformLabel, 7, 0);
 	layout->addWidget(mCbCropMetadata, 8, 0);
 	layout->setColumnStretch(3, 10);
+	layout->addWidget(mCbCropRectangle, 9, 0);
+	layout->setColumnStretch(3, 10);
+	layout->addWidget(mCropRectWidget, 10, 0);
 
 	connect(mResizeComboMode, SIGNAL(currentIndexChanged(int)), this, SLOT(modeChanged()));
 	connect(mResizeSbPercent, SIGNAL(valueChanged(double)), this, SLOT(updateHeader()));
@@ -2030,12 +2038,15 @@ void DkBatchTransformWidget::createLayout() {
 
 	connect(mRotateGroup, SIGNAL(buttonClicked(int)), this, SLOT(updateHeader()));
 	connect(mCbCropMetadata, SIGNAL(clicked()), this, SLOT(updateHeader()));
+	connect(mCbCropRectangle, SIGNAL(clicked()), this, SLOT(updateHeader()));
 }
 
 void DkBatchTransformWidget::applyDefault() {
 
 	mRbRotate0->setChecked(true);
 	mCbCropMetadata->setChecked(false);
+	mCbCropRectangle->setChecked(false);
+	mCropRectWidget->setRect(QRect());
 
 	mResizeSbPercent->setValue(100.0);
 	mResizeSbPx->setValue(1920);
@@ -2048,7 +2059,11 @@ void DkBatchTransformWidget::applyDefault() {
 
 bool DkBatchTransformWidget::hasUserInput() const {
 	
-	return !mRbRotate0->isChecked() || mCbCropMetadata->isChecked() || !(mResizeComboMode->currentIndex() == DkBatchTransform::resize_mode_default && mResizeSbPercent->value() == 100.0);
+	return 
+		!mRbRotate0->isChecked() || 
+		mCbCropMetadata->isChecked() || 
+		mCbCropRectangle->isChecked() ||
+		!(mResizeComboMode->currentIndex() == DkBatchTransform::resize_mode_default && mResizeSbPercent->value() == 100.0);
 }
 
 bool DkBatchTransformWidget::requiresUserInput() const {
@@ -2078,11 +2093,12 @@ void DkBatchTransformWidget::updateHeader() const {
 			txt += tr("Rotating by: %1").arg(getAngle());
 		}
 
-		if (mCbCropMetadata->isChecked()) {
+		if (mCbCropMetadata->isChecked() || mCbCropRectangle->isChecked()) {
 			if (!txt.isEmpty())
 				txt += " | ";
 			txt += tr("Crop");
 		}
+
 		emit newHeaderText(txt);
 	}
 }
@@ -2109,6 +2125,7 @@ void DkBatchTransformWidget::transferProperties(QSharedPointer<DkBatchTransform>
 		batchTransform->setProperties(
 			getAngle(), 
 			mCbCropMetadata->isChecked(),
+			mCbCropRectangle->isChecked() ? cropRect() : QRect(),
 			(float)mResizeSbPercent->value()/100.0f, 
 			(DkBatchTransform::ResizeMode)mResizeComboMode->currentIndex());
 	}
@@ -2116,6 +2133,7 @@ void DkBatchTransformWidget::transferProperties(QSharedPointer<DkBatchTransform>
 		batchTransform->setProperties(
 			getAngle(), 
 			mCbCropMetadata->isChecked(),
+			mCbCropRectangle->isChecked() ? cropRect() : QRect(),
 			(float)mResizeSbPx->value(), 
 			(DkBatchTransform::ResizeMode)mResizeComboMode->currentIndex(), 
 			(DkBatchTransform::ResizeProperty)mResizeComboProperties->currentIndex());
@@ -2140,8 +2158,12 @@ bool DkBatchTransformWidget::loadProperties(QSharedPointer<DkBatchTransform> bat
 	default: errored = true;
 	}
 
+	// crop
 	mCbCropMetadata->setChecked(batchTransform->cropMetatdata());
 
+	mCbCropRectangle->setChecked(batchTransform->cropFromRectangle());
+	mCropRectWidget->setRect(batchTransform->cropRectangle());
+
 	// resize
 	mResizeComboMode->setCurrentIndex(batchTransform->mode());
 	mResizeComboProperties->setCurrentIndex(batchTransform->prop());
@@ -2171,6 +2193,10 @@ int DkBatchTransformWidget::getAngle() const {
 	return 0;
 }
 
+QRect DkBatchTransformWidget::cropRect() const {
+	return mCropRectWidget->rect();
+}
+
 // Batch Buttons --------------------------------------------------------------------
 DkBatchButtonsWidget::DkBatchButtonsWidget(QWidget* parent) : DkWidget(parent) {
 	createLayout();
