@@ -98,6 +98,7 @@ class DkBatchConfig;
 class DkProgressBar;
 class DkSettingsWidget;
 class DkBatchPluginInterface;
+class DkRectWidget;
 
 class DkBatchContent {
 
@@ -523,6 +524,7 @@ signals:
 protected:
 	void createLayout();
 	int getAngle() const;
+	QRect cropRect() const;
 
 	QButtonGroup* mRotateGroup = 0;
 	QRadioButton* mRbRotate0 = 0;
@@ -532,6 +534,9 @@ protected:
 
 	QCheckBox* mCbCropMetadata = 0;
 
+	QCheckBox* mCbCropRectangle = 0;
+	DkRectWidget* mCropRectWidget = 0;
+
 	QComboBox* mResizeComboMode;
 	QComboBox* mResizeComboProperties;
 	QSpinBox* mResizeSbPx;
