@@ -296,7 +296,7 @@ void DkControlWidget::connectWidgets() {
 
 	// cropping
 	connect(mCropWidget, SIGNAL(cropImageSignal(const DkRotatingRect&, const QColor&, bool)), mViewport, SLOT(cropImage(const DkRotatingRect&, const QColor&, bool)));
-	connect(mCropWidget, SIGNAL(cancelSignal()), this, SLOT(hideCrop()));
+	connect(mCropWidget, SIGNAL(hideSignal()), this, SLOT(hideCrop()));
 
 	// comment widget
 	connect(mCommentWidget, SIGNAL(showInfoSignal(const QString&)), this, SLOT(setInfo(const QString&)));
@@ -573,7 +573,7 @@ bool DkControlWidget::closePlugin(bool askForSaving, bool force) {
 			qDebug() << "[DkControlWidget] I cannot close a plugin if the image container is NULL";
 	}
 
-	disconnect(vPlugin->getViewPort(), SIGNAL(showToolbar(QToolBar*, bool)), vPlugin->getMainWindow(), SLOT(showToolbar(QToolBar*, bool)));
+	disconnect(vPlugin->getViewPort(), SIGNAL(showToolBar(QToolBar*, bool)), vPlugin->getMainWindow(), SLOT(showToolBar(QToolBar*, bool)));
 
 	setPluginWidget(vPlugin, true);
 	plugin->setActive(false);		// handles states
