@@ -187,8 +187,8 @@ public slots:
 	void showStatusBar(bool show, bool permanent = true);
 	void showMenuBar(bool show);
 	void showToolbarsTemporarily(bool show);
-	void showToolbar(bool show);
-	void showToolbar(QToolBar* toolbar, bool show);
+	void showToolBar(bool show, bool permanent = true);
+	void showToolBar(QToolBar* toolbar, bool show);
 	void showGpsCoordinates();
 	void openFileWith(QAction* action);
 	void aboutDialog();
@@ -273,6 +273,7 @@ protected:
 	DkMainToolBar* mToolbar = 0;
 	DkQuickAccessEdit* mQuickAccessEdit = 0;
 	QToolBar* mMovieToolbar = 0;
+	Qt::ToolBarArea mMovieToolbarArea = Qt::NoToolBarArea;
 	DkQuickAccess* mQuickAccess = 0;
 
 	// file dialog
@@ -323,7 +324,6 @@ protected:
 	virtual void readSettings();
 
 	// plugin functions
-	void addPluginsToMenu();
 	bool mPluginMenuCreated = false;
 };
 
