@@ -284,13 +284,17 @@ DkGeneralPreference::DkGeneralPreference(QWidget* parent) : QWidget(parent) {
 
 void DkGeneralPreference::createLayout() {
 
-	// color settings
-	DkColorChooser* highlightColorChooser = new DkColorChooser(QColor(0, 204, 255), tr("Highlight Color"), this);
-	highlightColorChooser->setObjectName("highlightColor");
-	highlightColorChooser->setColor(&DkSettingsManager::param().display().highlightColor);
-	connect(highlightColorChooser, SIGNAL(accepted()), this, SLOT(showRestartLabel()));
+	// Theme
+	DkThemeManager tm;
+	QStringList themes = tm.cleanThemeNames(tm.getAvailableThemes());
 
-	DkColorChooser* iconColorChooser = new DkColorChooser(QColor(219, 89, 2, 255), tr("Icon Color"), this);
+	QComboBox* themeBox = new QComboBox(this);
+	themeBox->setObjectName("themeBox");
+	themeBox->addItems(themes);
+	themeBox->setCurrentText(tm.cleanThemeName(tm.getCurrentThemeName()));
+	connect(themeBox, SIGNAL(currentIndexChanged(int)), this, SLOT(showRestartLabel()));
+
+	DkColorChooser* iconColorChooser = new DkColorChooser(QColor(50, 50, 50, 255), tr("Icon Color"), this);
 	iconColorChooser->setObjectName("iconColor");
 	iconColorChooser->setColor(&DkSettingsManager::param().display().iconColor);
 	connect(iconColorChooser, SIGNAL(accepted()), this, SLOT(showRestartLabel()));
@@ -305,24 +309,11 @@ void DkGeneralPreference::createLayout() {
 	fullscreenColorChooser->setColor(&DkSettingsManager::param().slideShow().backgroundColor);
 	connect(fullscreenColorChooser, SIGNAL(accepted()), this, SLOT(showRestartLabel()));
 
-	DkColorChooser* fgdHUDColorChooser = new DkColorChooser(QColor(255, 255, 255, 255), tr("HUD Foreground Color"), this);
-	fgdHUDColorChooser->setObjectName("fgdHUDColor");
-	fgdHUDColorChooser->setColor(&DkSettingsManager::param().display().hudFgdColor);
-	connect(fgdHUDColorChooser, SIGNAL(accepted()), this, SLOT(showRestartLabel()));
-
-	DkColorChooser* bgHUDColorChooser = new DkColorChooser(QColor(0, 0, 0, 100), tr("HUD Background Color"), this);
-	bgHUDColorChooser->setObjectName("bgHUDColor");
-	bgHUDColorChooser->setColor((DkSettingsManager::param().app().appMode == DkSettings::mode_frameless) ?
-		&DkSettingsManager::param().display().bgColorFrameless : &DkSettingsManager::param().display().hudBgColor);
-	connect(bgHUDColorChooser, SIGNAL(accepted()), this, SLOT(showRestartLabel()));
-
 	DkGroupWidget* colorGroup = new DkGroupWidget(tr("Color Settings"), this);
-	colorGroup->addWidget(highlightColorChooser);
+	colorGroup->addWidget(themeBox);
 	colorGroup->addWidget(iconColorChooser);
 	colorGroup->addWidget(bgColorChooser);
 	colorGroup->addWidget(fullscreenColorChooser);
-	colorGroup->addWidget(fgdHUDColorChooser);
-	colorGroup->addWidget(bgHUDColorChooser);
 
 	// default pushbutton
 	QPushButton* defaultSettings = new QPushButton(tr("Reset All Settings"));
@@ -416,6 +407,7 @@ void DkGeneralPreference::createLayout() {
 	cbCheckForUpdates->setObjectName("checkForUpdates");
 	cbCheckForUpdates->setToolTip(tr("Check for updates on start-up."));
 	cbCheckForUpdates->setChecked(DkSettingsManager::param().sync().checkForUpdates);
+	cbCheckForUpdates->setDisabled(DkSettingsManager::param().sync().disableUpdateInteraction);
 
 	DkGroupWidget* generalGroup = new DkGroupWidget(tr("General"), this);
 	generalGroup->addWidget(cbRecentFiles);
@@ -460,7 +452,6 @@ void DkGeneralPreference::createLayout() {
 	contentLayout->setAlignment(Qt::AlignLeft);
 	contentLayout->addWidget(leftColumn);
 	contentLayout->addWidget(cbWidget);
-
 }
 
 void DkGeneralPreference::showRestartLabel() const {
@@ -483,6 +474,17 @@ void DkGeneralPreference::on_iconColor_resetClicked() const {
 	DkSettingsManager::param().display().defaultIconColor = true;
 }
 
+void DkGeneralPreference::on_themeBox_currentIndexChanged(const QString& text) const {
+
+	QString tn = text + ".css";
+
+	if (DkSettingsManager::param().display().themeName != tn) {
+		DkSettingsManager::param().display().themeName = tn;
+		DkThemeManager tm;
+		tm.loadTheme(tn);
+	}
+}
+
 void DkGeneralPreference::on_showRecentFiles_toggled(bool checked) const {
 
 	if (DkSettingsManager::param().app().showRecentFiles != checked)
@@ -598,7 +600,7 @@ void DkGeneralPreference::on_importSettings_clicked() {
 		DkUtils::getMainWindow(), 
 		tr("Import Settings"),
 		QDir::homePath(), 
-		"Nomacs Settings (*.nfo)");
+		"Nomacs Settings (*.ini)");
 
 	// user canceled?
 	if (filePath.isEmpty())
@@ -615,7 +617,7 @@ void DkGeneralPreference::on_exportSettings_clicked() {
 		DkUtils::getMainWindow(), 
 		tr("Export Settings"),
 		QDir::homePath(), 
-		"Nomacs Settings (*.nfo)");
+		"Nomacs Settings (*.ini)");
 
 	// user canceled?
 	if (filePath.isEmpty())
@@ -665,6 +667,12 @@ void DkDisplayPreference::createLayout() {
 	invertZoom->setToolTip(tr("If checked, the mouse wheel behaviour is inverted while zooming."));
 	invertZoom->setChecked(DkSettingsManager::param().display().invertZoom);
 
+	// zoom settings
+	QCheckBox* hQAntiAliasing = new QCheckBox(tr("Display Images with High Quality Anti Aliasing"), this);
+	hQAntiAliasing->setObjectName("hQAntiAliasing");
+	hQAntiAliasing->setToolTip(tr("NOTE: if checked, nomacs might be slow while zooming."));
+	hQAntiAliasing->setChecked(DkSettingsManager::param().display().highQualityAntiAliasing);
+
 	QLabel* interpolationLabel = new QLabel(tr("Show pixels if zoom level is above"), this);
 
 	QSpinBox* sbInterpolation = new QSpinBox(this);
@@ -677,6 +685,7 @@ void DkDisplayPreference::createLayout() {
 
 	DkGroupWidget* zoomGroup = new DkGroupWidget(tr("Zoom"), this);
 	zoomGroup->addWidget(invertZoom);
+	zoomGroup->addWidget(hQAntiAliasing);
 	zoomGroup->addWidget(interpolationLabel);
 	zoomGroup->addWidget(sbInterpolation);
 
@@ -845,6 +854,12 @@ void DkDisplayPreference::on_invertZoom_toggled(bool checked) const {
 		DkSettingsManager::param().display().invertZoom = checked;
 }
 
+void DkDisplayPreference::on_hQAntiAliasing_toggled(bool checked) const {
+
+	if (DkSettingsManager::param().display().highQualityAntiAliasing != checked)
+		DkSettingsManager::param().display().highQualityAntiAliasing = checked;
+}
+
 void DkDisplayPreference::on_zoomToFit_toggled(bool checked) const {
 
 	if (DkSettingsManager::param().display().zoomToFit != checked)
