@@ -31,6 +31,7 @@
 #include "DkUtils.h"
 #include "DkImageStorage.h"
 #include "DkQuickAccess.h"
+#include "DkBasicWidgets.h"
 
 #pragma warning(push, 0)	// no warnings from includes - begin
 #include <QToolBar>
@@ -885,7 +886,7 @@ void DkCropToolBar::loadSettings() {
 
 	mHorValBox->setValue(settings.value("AspectRatioHorizontal", 0).toInt());
 	mVerValBox->setValue(settings.value("AspectRatioVertical", 0).toInt());
-	mGuideBox->setCurrentIndex(settings.value("guides", 0).toInt());
+	mGuideBox->setCurrentIndex(settings.value("guides", 1).toInt());
 	mInvertAction->setChecked(settings.value("inverted", false).toBool());
 	mInfoAction->setChecked(settings.value("info", true).toBool());
 	mCbMeta->setChecked(settings.value("cropToMetadata", false).toBool());
@@ -1000,7 +1001,6 @@ void DkCropToolBar::createLayout() {
 	mGuideBox->setObjectName("guideBox");
 	mGuideBox->setToolTip(tr("Show Guides in the Preview"));
 	mGuideBox->setStatusTip(mGuideBox->toolTip());
-	mGuideBox->setCurrentIndex(1);
 
 	mInvertAction = new QAction(mIcons[invert_icon], tr("Invert Crop Tool Color"), this);
 	mInvertAction->setObjectName("invertAction");
@@ -1015,6 +1015,9 @@ void DkCropToolBar::createLayout() {
 	mCbMeta = new QCheckBox(tr("Crop to Metadata"), this);
 	mCbMeta->setChecked(false);
 
+	mCropRect = new DkRectWidget(QRect(), this);
+	mCropRect->setObjectName("cropRect");
+
 	addAction(cropAction);
 	addAction(mPanAction);
 	addAction(cancelAction);
@@ -1031,6 +1034,11 @@ void DkCropToolBar::createLayout() {
 	addAction(mInvertAction);
 	addAction(mInfoAction);
 	addWidget(mCbMeta);
+	addSeparator();
+	addWidget(mCropRect);
+
+	connect(mCropRect, SIGNAL(updateRectSignal(const QRect&)), this, SIGNAL(updateRectSignal(const QRect&)));
+
 }
 
 void DkCropToolBar::setVisible(bool visible) {
@@ -1054,6 +1062,10 @@ void DkCropToolBar::setAspectRatio(const QPointF& aRatio) {
 	mVerValBox->setValue(aRatio.y());
 }
 
+void DkCropToolBar::setRect(const QRect & r) {
+	mCropRect->setRect(r);
+}
+
 void DkCropToolBar::on_cropAction_triggered() {
 	emit cropSignal(mCbMeta->isChecked());
 }
