@@ -304,7 +304,7 @@ void DkViewPort::setImage(QImage newImg) {
 
 	mController->getPlayer()->startTimer();
 	mController->getOverview()->setImage(newImg);	// TODO: maybe we could make use of the image pyramid here
-	mController->stopLabels();
+	//mController->stopLabels();
 
 	mOldImgRect = mImgRect;
 	
@@ -927,7 +927,13 @@ void DkViewPort::loadMovie() {
 	if (mMovie)
 		mMovie->stop();
 
-	mMovie = QSharedPointer<QMovie>(new QMovie(mLoader->filePath()));
+	// check if it truely a movie (we need this for we don't know if webp is actually animated)
+	QSharedPointer<QMovie> m(new QMovie(mLoader->filePath()));
+	if (m->frameCount() == 1)
+		return;
+
+	mMovie = m;
+
 	connect(mMovie.data(), SIGNAL(frameChanged(int)), this, SLOT(update()));
 	mMovie->start();
 
@@ -1358,8 +1364,10 @@ QMimeData * DkViewPort::createMime() const {
 
 	QMimeData* mimeData = new QMimeData;
 
-	if (QFileInfo(mLoader->filePath()).exists() && !mLoader->isEdited())
+	if (QFileInfo(mLoader->filePath()).exists() && !mLoader->isEdited()) {
 		mimeData->setUrls(urls);
+		mimeData->setText(fileUrl.toLocalFile());
+	}
 	else if (!getImage().isNull())
 		mimeData->setImageData(getImage());
 
@@ -1593,9 +1601,12 @@ void DkViewPort::loadFile(const QString& filePath) {
 	else if (mLoader)
 		mLoader->load(filePath);
 
-	qDebug() << "sync mode: " << (DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display);
-	if ((qApp->keyboardModifiers() == mAltMod || DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display) && (hasFocus() || mController->hasFocus()) && mLoader->hasFile())
-		tcpLoadFile(0, filePath);
+	// diem: I removed this line for a) we don't support remote displays anymore and be: https://github.com/nomacs/nomacs/issues/219
+	//qDebug() << "sync mode: " << (DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display);
+	//if ((qApp->keyboardModifiers() == mAltMod || DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_remote_display) && 
+	//	(hasFocus() || mController->hasFocus()) && 
+	//	mLoader->hasFile())
+	//	tcpLoadFile(0, filePath);
 }
 
 void DkViewPort::reloadFile() {
