@@ -1105,7 +1105,7 @@ QVector<QAction*> DkRatingLabelBg::getActions() const {
 void DkRatingLabelBg::paintEvent(QPaintEvent *event) {
 
 	QPainter painter(this);
-	painter.fillRect(QRect(QPoint(), this->size()), mBgCol);
+	painter.fillRect(QRect(QPoint(), this->size()), DkSettingsManager::param().display().hudBgColor);
 	painter.end();
 
 	DkRatingLabel::paintEvent(event);
@@ -1465,7 +1465,6 @@ void DkTransformRect::mouseMoveEvent(QMouseEvent *event) {
 		
 		QPointF pt = initialPos+event->globalPos()-posGrab;
 		emit ctrlMovedSignal(parentIdx, pt, event->modifiers(), true);
-		qDebug() << "accepted false...";
 	}
 
 	QWidget::mouseMoveEvent(event);
@@ -1507,9 +1506,6 @@ DkEditableRect::DkEditableRect(const QRectF& rect, QWidget* parent, Qt::WindowFl
 void DkEditableRect::reset() {
 
 	mRect = QRectF();
-	//for (int idx = 0; idx < ctrlPoints.size(); idx++)
-	//	ctrlPoints[idx]->reset();
-
 }
 
 QPointF DkEditableRect::map(const QPointF &pos) {
@@ -1653,14 +1649,6 @@ void DkEditableRect::paintEvent(QPaintEvent *event) {
 	painter.setBrush(mBrush);
 	painter.drawPath(path);
 
-	//for (int idx = 0; idx < p.size()-1; idx++) {
-	//	
-	//	QPointF c = p[idx];
-	//	painter.setBrush(QColor(255, 255, 255));
-	//	painter.setPen(QColor(255, 255, 255));
-	//	painter.drawText(c+QPointF(10,10), QString::number(idx));
-	//}
-
 	drawGuide(&painter, p, mPaintMode);
 	
 	//// debug
@@ -1700,6 +1688,15 @@ void DkEditableRect::paintEvent(QPaintEvent *event) {
 	QWidget::paintEvent(event);
 }
 
+QRect DkEditableRect::rect() const {
+	
+	QRect r;
+	r.setTopLeft(mRect.getCenter().toPoint());
+	r.setSize(mRect.size());
+
+	return r;
+}
+
 void DkEditableRect::drawGuide(QPainter* painter, const QPolygonF& p, int paintMode) {
 
 	if (p.isEmpty() || paintMode == no_guide)
@@ -1875,15 +1872,32 @@ void DkEditableRect::mouseMoveEvent(QMouseEvent *event) {
 		int height = qRound(DkVector(p[1]-p[0]).norm());
 		int width = qRound(DkVector(p[3]-p[0]).norm());
 
+		// show coordinates
+		QString info;
+		QPoint tl;
+
+		if (sAngle == 0.0f || fabs(sAngle) == 90.0f) {
+			tl = mRect.getTopLeft().toPoint();
+			info += "x: ";
+		}
+		else {
+			tl = mRect.getCenter().toPoint();
+			info += "center x: ";
+		}
+		info += QString::number(tl.x()) + ", y: ";
+		info += QString::number(tl.y()) + " | ";
+		info += QString::number(width) + " x ";
+		info += QString::number(height) + " px | ";
+		info += QString::number(sAngle) + dk_degree_str;
+
 		if (mShowInfo) {
+
 			QToolTip::showText(event->globalPos(),
-				QString::number(width) + " x " +
-				QString::number(height) + " px\n" +
-				QString::number(sAngle) + dk_degree_str,
+				info,
 				this);
 		}
 
-		DkStatusBarManager::instance().setMessage(QString::number(width) + " x " + QString::number(height) + " px | " + QString::number(sAngle) + dk_degree_str);
+		DkStatusBarManager::instance().setMessage(info);
 	}
 
 	//QWidget::mouseMoveEvent(event);
@@ -1921,6 +1935,7 @@ void DkEditableRect::applyTransform() {
 	mTtform.reset();
 	update();
 
+	emit updateRectSignal(rect());
 }
 
 void DkEditableRect::keyPressEvent(QKeyEvent *event) {
@@ -1933,13 +1948,11 @@ void DkEditableRect::keyPressEvent(QKeyEvent *event) {
 
 void DkEditableRect::keyReleaseEvent(QKeyEvent *event) {
 
-	qDebug() << "key pressed rect";
 	QWidget::keyPressEvent(event);
 }
 
 void DkEditableRect::setPaintHint(int paintMode /* = DkCropToolBar::no_guide */) {
 
-	qDebug() << "painting mode: " << paintMode;
 	this->mPaintMode = paintMode;
 	update();
 }
@@ -1961,6 +1974,14 @@ void DkEditableRect::setShowInfo(bool showInfo) {
 	this->mShowInfo = showInfo;
 }
 
+void DkEditableRect::setRect(const QRect & rect) {
+	
+	mRect.setCenter(rect.topLeft());
+	mRect.setSize(rect.size());
+
+	update();
+}
+
 void DkEditableRect::setAngle(double angle, bool apply) {
 
 	DkVector c(mRect.getCenter());
@@ -2009,8 +2030,10 @@ void DkCropWidget::createToolbar() {
 
 	cropToolbar = new DkCropToolBar(tr("Crop Toolbar"), this);
 
+	connect(cropToolbar, SIGNAL(updateRectSignal(const QRect&)), this, SLOT(setRect(const QRect&)));
+
 	connect(cropToolbar, SIGNAL(cropSignal(bool)), this, SLOT(crop(bool)));
-	connect(cropToolbar, SIGNAL(cancelSignal()), this, SIGNAL(cancelSignal()));
+	connect(cropToolbar, SIGNAL(cancelSignal()), this, SIGNAL(hideSignal()));
 	connect(cropToolbar, SIGNAL(aspectRatio(const DkVector&)), this, SLOT(setFixedDiagonal(const DkVector&)));
 	connect(cropToolbar, SIGNAL(angleSignal(double)), this, SLOT(setAngle(double)));
 	connect(cropToolbar, SIGNAL(panSignal(bool)), this, SLOT(setPanning(bool)));
@@ -2019,6 +2042,7 @@ void DkCropWidget::createToolbar() {
 	connect(cropToolbar, SIGNAL(showInfo(bool)), this, SLOT(setShowInfo(bool)));
 	connect(this, SIGNAL(angleSignal(double)), cropToolbar, SLOT(angleChanged(double)));
 	connect(this, SIGNAL(aRatioSignal(const QPointF&)), cropToolbar, SLOT(setAspectRatio(const QPointF&)));
+	connect(this, SIGNAL(updateRectSignal(const QRect&)), cropToolbar, SLOT(setRect(const QRect&)));
 
 	cropToolbar->loadSettings();	// need to this manually after connecting the slots
 
@@ -2038,6 +2062,7 @@ void DkCropWidget::crop(bool cropToMetadata) {
 
 	setVisible(false);
 	setWindowOpacity(0);
+	emit hideSignal();
 }
 
 void DkCropWidget::setVisible(bool visible) {
@@ -2045,7 +2070,7 @@ void DkCropWidget::setVisible(bool visible) {
 	if (visible && !cropToolbar)
 		createToolbar();
 
-	emit showToolbar(cropToolbar, visible);
+	emit showToolBar(cropToolbar, visible);
 	DkEditableRect::setVisible(visible);
 }
 
@@ -2130,7 +2155,7 @@ DkHistogram::~DkHistogram() {
 void DkHistogram::paintEvent(QPaintEvent*) {
 
 	QPainter painter(this);
-	painter.fillRect(1, 1, width(), height(), mBgCol);
+	painter.fillRect(1, 1, width(), height(), DkSettingsManager::param().display().hudBgColor);
 
 	int numTextLines;
 	if (mDisplayMode == DisplayMode::histogram_mode_simple) {
